Learn R Programming

mixedMem (version 1.0.2)

gmv_theta: Point estimates from Gross and Manrique-Vallier 2014

Description

The point estimates for theta from the original Gross and Manrique-Vallier 2014 analysis. It is a 3 by 19 by 3 dimensional array with the first dimension corresponding to group, the second dimension corresponding to variable, and the 3rd dimension corresponding to candidate choices (Agree, Can't Decide, Disagree). Note that Gross and Manrique-Vallier do not report results for group 3, so those are left as 0's in the data.

Usage

data(gmv_theta)

Arguments

References

Gross, J.H. and Manrique-Vallier, D. "A Mixed-Membership Approach to the Assessment of Political Ideology from Survey Responses." in Airoldi, E. M., Blei, D. M., Erosheva, E. A., and Fienberg, S. E. Handbook of Mixed Membership Models and Its Applications. Chapman & Hall/CRC, 2014