vizMem plots estimates for the group membership scores of each individual. This is the function called by the mixedMemModel class
generic plot function.
vizMem(model, compare = NULL, main = "Estimated Membership", nrow = NULL, ncol = NULL, indices = NULL, groupNames = NULL, fitNames = NULL)mixedMemModel object that will be plotted.model$phi which contains parameters to compare
against the fitted model.nrow * ncol then multiple plots will be produced.This is the function called by the plot generic function for mixedMemModel objects.