Usage
vizTheta(model, compare = NULL, main = "Estimated Theta", varNames = NULL, groupNames = NULL, nrow = NULL, fitNames = NULL, indices = NULL)
Arguments
model
the mixedMemModel object that will be plotted.
compare
an array of the same dimensions as model$theta which contains values to compare against the fitted value.
main
the main figure title.
varNames
a vector of strings specifying labels for each variable.
groupNames
a vector of strings specifying labels for each sub-population.
nrow
the number of rows in each plot. If the argument is not specified, all variables will appear in one plot.
fitNames
the names of the models plotted.
indices
a vector which indicates specific variables to plot. If the argument is not specified, all variables will be plotted. If the number of variables
to plot is greater than nrow, then multiple plots will be produced.