Learn R Programming

mixedMem (version 1.0.2)

vizTheta: Mixed Membership Visualization

Description

Plots $\theta$, the parameters which govern the distributions of variables in a mixed membership model. $\theta_{j,k}$ governs the distribution of variable j for sub-population k. The model fit is shown in black, and the comparison (if available) is shown in red.

Usage

vizTheta(model, compare = NULL, main = "Estimated Theta", varNames = NULL,
  groupNames = NULL, nrow = NULL, fitNames = NULL, indices = NULL)

Arguments

model
the mixedMemModel object that will be plotted
compare
estimates to compare against. Should be an array with same dimensions as model$theta
main
title of plot
varNames
vector specifying labels for each variable
groupNames
vector specifying labels for each sub-population
nrow
the number of rows in each plot. If the argument is not specified, all variables will appear in one plot
fitNames
the names of the models plotted
indices
a vector which indicates specific variables to plot. If the argument is not specified, all variables will be plotted

Details

This is the function called by the plot generic function for mixedMemModel objects