Usage
vizTheta(model, compare = NULL, main = "Estimated Theta", varNames = NULL,
groupNames = NULL, nrow = NULL, fitNames = NULL, indices = NULL)
Arguments
model
the mixedMemModel object that will be plotted
compare
estimates to compare against. Should be an array with same dimensions as model$theta
varNames
vector specifying labels for each variable
groupNames
vector specifying labels for each sub-population
nrow
the number of rows in each plot. If the argument is not specified, all variables will appear in one plot
fitNames
the names of the models plotted
indices
a vector which indicates specific variables to plot. If the argument is not specified, all variables will be plotted